The logo design uses the Monoid typeface a open source webfont that was
developed by Andreas Larsen and contributors in 2015 under the MIT or SIL
licenses.
More information at https://github.com/larsenwork/monoid

The colors include pure black (`#000000`), pure white (`#FFFFFF`), 30% gray for the
box shadow (`#B3B3B3`) and an accent color (`#008C70`) that can be understood as a
tone of "teal"

A vector representation of the design can be found in the files:

- `configupdater.svg`: produced with [Inkscape](https://inkscape.org/), might
    contain specific markup not understood by other software. This file
    should be preferred when using Inkscape.
- `configupdater_plain.svg`: a "plain" version of the same file that in theory
    should not contain inkscape-specific markup. This file might be preferred
    when using other editors.
- `icon.svg`: another Inkscape file that only contains, this time without the
    "ConfigUpdater" name, just the icon image.
